@@ -72,7 +72,25 @@ class DialogHandler:
 		dialog.set_filter(file_filter)
 		dialog.show_all()
 		if dialog.run() == gtk.RESPONSE_OK:
-			command_entry.set_text(dialog.get_filename())
+			command = dialog.get_filename()
+			new_command = ''
+			length, i = len(command), 0
+			while i < length:
+				char = command[i]
+				if not (ord(char) >= ord('a') and ord(char) <= ord('z')):
+					if not (ord(char) >= ord('A') and ord(char) <= ord('Z')):
+						if char == '/':
+							new_command += char
+						else:
+							new_command += '\\' + char
+					else:
+						new_command += char
+				else:
+					new_command += char
+				i += 1
+			command_entry.set_completion(None)
+			command_entry.set_text(new_command)
+			command_entry.set_completion(self.command_completion)
 		dialog.destroy()
 
 	def showIconDialog(self, button):
@@ -198,7 +216,6 @@ class DialogHandler:
 		name_entry = self.tree.get_widget('item_name_entry')
 		comment_entry = self.tree.get_widget('item_comment_entry')
 		command_entry = self.tree.get_widget('item_command_entry')
-		command_entry.set_completion(self.command_completion)
 		command_button = self.tree.get_widget('item_command_button')
 		term_check = self.tree.get_widget('item_terminal_check')
 
@@ -214,11 +231,18 @@ class DialogHandler:
 			label = gtk.Label('No Icon')
 			icon_button.add(label)
 			icon_button.icon_path = None
-		name_entry.set_text(self.item.get_name())
+		name_entry.set_text(cgi.escape(self.item.get_name()))
 		if self.item.get_comment():
 			comment_entry.set_text(self.item.get_comment())
 		if self.item.get_exec():
-			command_entry.set_text(self.item.get_exec())
+			command = self.item.get_exec()
+			#escape a few common things in commands
+			command = command.replace('\r', '\\r')
+			command = command.replace('\n', '\\n')
+			command = command.replace('\t', '\\t')
+			command_entry.set_text(cgi.escape(command))
+		#hack to work around weird bug
+		command_entry.set_completion(self.command_completion)
 		if self.item.get_launch_in_terminal():
 			term_check.set_active(True)
 		dialog.show_all()
@@ -247,7 +271,7 @@ class DialogHandler:
 			self.first_change = False
 		if self.in_revert:
 			self.in_revert = False
-			self.saveItemChanges()
+			self.saveItem(self.item_original_values)
 			return
 		if not self.in_dialog_setup:
 			self.tree.get_widget('item_revert_button').set_sensitive(True)
@@ -400,13 +424,14 @@ class DialogHandler:
 			name_entry.get_text(),
 			comment_entry.get_text()
 			)
-		self.in_dialog_setup = False
 		#hack to make undo work
 		self.first_change = True
+		self.in_dialog_setup = False
 		can_close = False
 		while can_close == False:
 			response = dialog.run()
 			can_close = responseChecker(response)
+		self.menu_original_values = ()
 		dialog.destroy()
 
 	def on_menu_contents_changed(self, garbage):
@@ -417,7 +442,7 @@ class DialogHandler:
 			self.first_change = False
 		if self.in_revert:
 			self.in_revert = False
-			self.saveMenuChanges()
+			self.saveMenu(self.menu_original_values)
 			return
 		if not self.in_dialog_setup:
 			self.tree.get_widget('menu_revert_button').set_sensitive(True)
